summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/uml.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/uml.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/uml.h')
-rw-r--r--umbrello/umbrello/uml.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/umbrello/umbrello/uml.h b/umbrello/umbrello/uml.h
index 973f4d03..13cbce16 100644
--- a/umbrello/umbrello/uml.h
+++ b/umbrello/umbrello/uml.h
@@ -53,10 +53,10 @@ class KTabWidget;
class KToolBarButton;
class KPopupMenu;
-// Qt forward declarations
+// TQt forward declarations
class TQWidgetStack;
class TQMenuData;
-class QClipboard;
+class TQClipboard;
class TQToolButton;
class TQCustomEvent;
@@ -77,11 +77,12 @@ class TQCustomEvent;
class UMLApp : public KDockMainWindow {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor. Calls all init functions to create the application.
*/
- UMLApp(TQWidget* parent=0, const char* name=0);
+ UMLApp(TQWidget* tqparent=0, const char* name=0);
/**
* Standard deconstructor.
@@ -246,7 +247,7 @@ public:
void setDiagramMenuItemsState(bool bState);
/**
* Returns the widget used as the parent for UMLViews.
* @return The main view widget.
*/
TQWidget* getMainViewWidget();
@@ -339,7 +340,7 @@ protected:
/**
* Save general Options like all bar positions and status
- * as well as the geometry and the recent file list to
+ * as well as the tqgeometry and the recent file list to
* the configuration file.
*/
void saveOptions();
@@ -532,9 +533,9 @@ public slots:
void slotViewStatusBar();
/**
- * Autolayouts the current class diagram
+ * Autotqlayouts the current class diagram
*/
- void slotAutolayout();
+ void slotAutotqlayout();
/**
* Changes the statusbar contents for the standard label
@@ -850,7 +851,7 @@ private:
void readOptionState();
/**
- * Initialize Qt's global clipboard support for the application.
+ * Initialize TQt's global clipboard support for the application.
*/
void initClip();
@@ -958,7 +959,7 @@ private:
KAction* deleteSelectedWidget;
KAction* deleteDiagram;
#ifdef HAVE_DOT
- KAction* autolayout;
+ KAction* autotqlayout;
#endif
KAction* changeTabLeft;
@@ -983,13 +984,13 @@ private:
bool m_loading;
/**
* Shows, and is parent of, all the UMLViews (diagrams)
* if tabbed diagrams are not enabled.
*/
TQWidgetStack* m_viewStack;
/**
* Shows, and is parent of, all the UMLViews (diagrams)
* if tabbed diagrams are enabled.
*/
KTabWidget* m_tabWidget;
@@ -246,7 +247,7 @@ public:
void setDiagramMenuItemsState(bool bState);
/**
- * Returns the widget used as the parent for UMLViews.
+ * Returns the widget used as the tqparent for UMLViews.
* @return The main view widget.
*/
@@ -983,13 +984,13 @@ private:
bool m_loading;
/**
- * Shows, and is parent of, all the UMLViews (diagrams)
+ * Shows, and is tqparent of, all the UMLViews (diagrams)
* if tabbed diagrams are not enabled.
*/
@@ -983,13 +984,13 @@ private:
TQWidgetStack* m_viewStack;
/**
- * Shows, and is parent of, all the UMLViews (diagrams)
+ * Shows, and is tqparent of, all the UMLViews (diagrams)
* if tabbed diagrams are enabled.
*/